@@ -1,13 +1,27 @@
 /*
  * Copyright (c) 2010 David Galindo <nowheremanmail@gmail.com>
+ *
+ *
+ * libhildonmm-dev   libhildon1-dev libhildonnotify-dev libhildonnotifymm-dev libhildonmm-dev
  */
 
+
+//#include <gtkmm.h>
+//#include <hildonmm.h>
+//#include <gtk.h>//hildon-notify/hildon/hildon-notification.h>
+
+
+//#include <gtk/gtk.h>
+//#include <hildon/hildon.h>
+//#include <hildon/hildon-notification.h>
+
+
 #include "eWallet.h"
 #include "Constants.h"
 #include "DetailedWindow.h"
 #include <Qt>
 #include <QDesktopServices>
-//#include <QtXml>
+
 
 #include "camera.h"
 
@@ -41,6 +55,9 @@ protected:
 DetailWindow::DetailWindow(Target * _target, const QString & groupName, int istemplate, bool edit, eWallet *paTarget, QWidget *parent) :
 		QMainWindow(parent)
 {
+
+	//hildon_banner_show_information(NULL, NULL, "HELLO CAMERA");
+
 	this->setAttribute(Qt::WA_Maemo5StackedWindow);
 	if (!edit)
 		connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged(int)));
@@ -120,7 +137,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 		menuBar()->addAction(tr("Delete Back Pict."), this, SLOT(deleteCardBack()));
 		menuBar()->addAction(tr("Modify fields"), this, SLOT(modifyFields()));
 
-		menuBar()->addAction(tr("Camera"), this, SLOT(takePicture()));
+		//menuBar()->addAction(tr("Camera"), this, SLOT(takePicture()));
 
 		//TODO menuBar()->addAction("Delete field", this, SLOT(addNewField()));
 		//TODO menuBar()->addAction("Modify field", this, SLOT(addNewField()));
@@ -1000,6 +1017,9 @@ void DetailWindow::photoTake (QImage* image) {
 }
 
 void DetailWindow::takePicture () {
+
+
+
 	QCamera * cam = new QCamera;
 
 	connect (cam, SIGNAL(photoReady (QImage*)), this, SLOT(photoTake(QImage*)));
