@@ -4,52 +4,52 @@
 <context>
     <name>CreateFieldDialog</name>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1118"/>
+        <location filename="../../DetailedWindow.cpp" line="1142"/>
         <source>Name</source>
         <translation>Nombre</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1131"/>
+        <location filename="../../DetailedWindow.cpp" line="1155"/>
         <source>Type</source>
         <translation>Tipo</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1141"/>
+        <location filename="../../DetailedWindow.cpp" line="1165"/>
         <source>String</source>
         <translation>Cadena Carácteres</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1142"/>
+        <location filename="../../DetailedWindow.cpp" line="1166"/>
         <source>Text</source>
         <translation>Texto</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1143"/>
+        <location filename="../../DetailedWindow.cpp" line="1167"/>
         <source>Date</source>
         <translation>Fecha</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1144"/>
+        <location filename="../../DetailedWindow.cpp" line="1168"/>
         <source>Number</source>
         <translation>Número</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1145"/>
+        <location filename="../../DetailedWindow.cpp" line="1169"/>
         <source>Phone Number</source>
         <translation>Número móvil</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1146"/>
+        <location filename="../../DetailedWindow.cpp" line="1170"/>
         <source>Password</source>
         <translation>Password</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1147"/>
+        <location filename="../../DetailedWindow.cpp" line="1171"/>
         <source>URL</source>
         <translation>URL</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1152"/>
+        <location filename="../../DetailedWindow.cpp" line="1176"/>
         <source>Order</source>
         <translation>Orden</translation>
     </message>
@@ -57,265 +57,260 @@
 <context>
     <name>DetailWindow</name>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="65"/>
+        <location filename="../../DetailedWindow.cpp" line="82"/>
         <source>Copy of </source>
         <translation>Copia de </translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="112"/>
-        <location filename="../../DetailedWindow.cpp" line="335"/>
+        <location filename="../../DetailedWindow.cpp" line="129"/>
+        <location filename="../../DetailedWindow.cpp" line="352"/>
         <source>Save</source>
         <translation>Guardar</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="114"/>
-        <location filename="../../DetailedWindow.cpp" line="781"/>
-        <location filename="../../DetailedWindow.cpp" line="794"/>
+        <location filename="../../DetailedWindow.cpp" line="131"/>
+        <location filename="../../DetailedWindow.cpp" line="798"/>
+        <location filename="../../DetailedWindow.cpp" line="811"/>
         <source>Delete</source>
         <translation>Borrar</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="115"/>
+        <location filename="../../DetailedWindow.cpp" line="132"/>
         <source>Change Face Pict.</source>
         <translation>Cambiar imagen</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="116"/>
+        <location filename="../../DetailedWindow.cpp" line="133"/>
         <source>Mirror Face Pict.</source>
         <translation>Girar imagen</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="117"/>
+        <location filename="../../DetailedWindow.cpp" line="134"/>
         <source>Change Back Pict.</source>
         <translation>Cambiar reverso</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="118"/>
+        <location filename="../../DetailedWindow.cpp" line="135"/>
         <source>Mirror Back Pict.</source>
         <translation>Girar reverso</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="119"/>
+        <location filename="../../DetailedWindow.cpp" line="136"/>
         <source>Delete Face Pict.</source>
         <translation>Borrar imagen</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="120"/>
+        <location filename="../../DetailedWindow.cpp" line="137"/>
         <source>Delete Back Pict.</source>
         <translation>Borrar reverso</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="121"/>
+        <location filename="../../DetailedWindow.cpp" line="138"/>
         <source>Modify fields</source>
         <translation>Modificar campos</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="123"/>
-        <source>Camera</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../DetailedWindow.cpp" line="129"/>
+        <location filename="../../DetailedWindow.cpp" line="146"/>
         <source>New Card</source>
         <translation>Nueva tarjeta</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="130"/>
+        <location filename="../../DetailedWindow.cpp" line="147"/>
         <source>Edit Card</source>
         <translation>Modificar tarjeta</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="131"/>
+        <location filename="../../DetailedWindow.cpp" line="148"/>
         <source>New Card like this</source>
         <translation>Nueva tarjeta como esta</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="132"/>
+        <location filename="../../DetailedWindow.cpp" line="149"/>
         <source>Duplicate Card</source>
         <translation>Duplicar tarjeta</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="133"/>
+        <location filename="../../DetailedWindow.cpp" line="150"/>
         <source>Export Face Pict.</source>
         <translation>Extraer imagen</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="134"/>
+        <location filename="../../DetailedWindow.cpp" line="151"/>
         <source>Export Back Pict.</source>
         <translation>Extraer reverso</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="161"/>
+        <location filename="../../DetailedWindow.cpp" line="178"/>
         <source>Name</source>
         <translation>Nombre</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="172"/>
+        <location filename="../../DetailedWindow.cpp" line="189"/>
         <source>Group Name</source>
         <translation>Nombre del grupo</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="190"/>
+        <location filename="../../DetailedWindow.cpp" line="207"/>
         <source>Membership Info</source>
         <translation>Información de asociación</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="191"/>
+        <location filename="../../DetailedWindow.cpp" line="208"/>
         <source>Password</source>
         <translation>Password</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="192"/>
+        <location filename="../../DetailedWindow.cpp" line="209"/>
         <source>Credit Card</source>
         <translation>Targeta de crédito</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="193"/>
+        <location filename="../../DetailedWindow.cpp" line="210"/>
         <source>Bank Account</source>
         <translation>Cuenta bancaria</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="194"/>
+        <location filename="../../DetailedWindow.cpp" line="211"/>
         <source>Health Numbers</source>
         <translation>Número Seguridad social</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="195"/>
+        <location filename="../../DetailedWindow.cpp" line="212"/>
         <source>Passport Info</source>
         <translation>Pasaporte</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="196"/>
+        <location filename="../../DetailedWindow.cpp" line="213"/>
         <source>Note Card</source>
         <translation>Nota</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="197"/>
+        <location filename="../../DetailedWindow.cpp" line="214"/>
         <source>Car Info</source>
         <translation>Coche</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="198"/>
+        <location filename="../../DetailedWindow.cpp" line="215"/>
         <source>Cellular Phone</source>
         <translation>Teléfono móbil</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="199"/>
+        <location filename="../../DetailedWindow.cpp" line="216"/>
         <source>Serial Number Software</source>
         <translation>Número de serie Software</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="200"/>
+        <location filename="../../DetailedWindow.cpp" line="217"/>
         <source>Serial Number Hardware</source>
         <translation>Número de serie Hardware</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="201"/>
+        <location filename="../../DetailedWindow.cpp" line="218"/>
         <source>Web site</source>
         <translation>Web</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="202"/>
+        <location filename="../../DetailedWindow.cpp" line="219"/>
         <source>ID Card</source>
         <translation>DNI</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="203"/>
+        <location filename="../../DetailedWindow.cpp" line="220"/>
         <source>Social Security Number</source>
         <translation>Seguridad social</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="204"/>
+        <location filename="../../DetailedWindow.cpp" line="221"/>
         <source>Email Account</source>
         <translation>Cuenta de correo</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="205"/>
+        <location filename="../../DetailedWindow.cpp" line="222"/>
         <source>Driver&apos;s License</source>
         <translation>Carnet de conducir</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="206"/>
+        <location filename="../../DetailedWindow.cpp" line="223"/>
         <source>Others</source>
         <translation>Otros</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="210"/>
+        <location filename="../../DetailedWindow.cpp" line="227"/>
         <source>Type</source>
         <translation>Tipo</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="516"/>
-        <location filename="../../DetailedWindow.cpp" line="562"/>
+        <location filename="../../DetailedWindow.cpp" line="533"/>
+        <location filename="../../DetailedWindow.cpp" line="579"/>
         <source>Click to see</source>
         <translation>Pulsa para ver</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="615"/>
+        <location filename="../../DetailedWindow.cpp" line="632"/>
         <source>Card description is missing</source>
         <translation>Tarjeta sin descripción</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="625"/>
+        <location filename="../../DetailedWindow.cpp" line="642"/>
         <source>Type card is missing</source>
         <translation>Tarjeta sin tipo</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="779"/>
-        <location filename="../../DetailedWindow.cpp" line="792"/>
+        <location filename="../../DetailedWindow.cpp" line="796"/>
+        <location filename="../../DetailedWindow.cpp" line="809"/>
         <source>Edit</source>
         <translation>Modificar</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="780"/>
-        <location filename="../../DetailedWindow.cpp" line="793"/>
+        <location filename="../../DetailedWindow.cpp" line="797"/>
+        <location filename="../../DetailedWindow.cpp" line="810"/>
         <source>Mirror</source>
         <translation>Imagen espejo</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="784"/>
+        <location filename="../../DetailedWindow.cpp" line="801"/>
         <source>Export Face</source>
         <translation>Extraer imagen</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="797"/>
+        <location filename="../../DetailedWindow.cpp" line="814"/>
         <source>Export Back</source>
         <translation>Extraer reverso</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="818"/>
+        <location filename="../../DetailedWindow.cpp" line="835"/>
         <source>Choose card face image file</source>
         <translation>Elije una imagen</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="820"/>
-        <location filename="../../DetailedWindow.cpp" line="962"/>
+        <location filename="../../DetailedWindow.cpp" line="837"/>
+        <location filename="../../DetailedWindow.cpp" line="979"/>
         <source>Images (*.png);;</source>
         <translation>Imagenes PNG (*.png)</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="833"/>
+        <location filename="../../DetailedWindow.cpp" line="850"/>
         <source>Choose card face image</source>
         <translation>Elije una imagen</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="835"/>
-        <location filename="../../DetailedWindow.cpp" line="978"/>
+        <location filename="../../DetailedWindow.cpp" line="852"/>
+        <location filename="../../DetailedWindow.cpp" line="995"/>
         <source>Images (*.png *.jpg *.gif *.jpeg);;</source>
         <translation>Imagenes (*.png *.jpg *.gif *.jpeg)</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="960"/>
+        <location filename="../../DetailedWindow.cpp" line="977"/>
         <source>Choose card back image file</source>
         <translation>Elije una imagen para el reverso</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="976"/>
+        <location filename="../../DetailedWindow.cpp" line="993"/>
         <source>Choose card back image</source>
         <translation>Elije una imagen para el reverso</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1028"/>
+        <location filename="../../DetailedWindow.cpp" line="1052"/>
         <source>Are you sure you want to discard changes?</source>
         <translation>¿Está seguro que no quiere guardar los cambios?</translation>
     </message>
@@ -860,7 +855,7 @@
     <message>
         <location filename="../../eWallet.cpp" line="1615"/>
         <source>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;qtWallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Developed by &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icons by http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;if you think that qtWallet is useful for you, please&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt;&lt;/qt&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;Wallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Desarrollado por &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Iconos por http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;Si piensas que Wallet es util para ti, puedes &lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONAR&lt;/a&gt;&lt;/qt&gt;</translation>
     </message>
     <message>
         <location filename="../../eWallet.cpp" line="1654"/>
