@@ -4,52 +4,52 @@
 <context>
     <name>CreateFieldDialog</name>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1049"/>
+        <location filename="../../DetailedWindow.cpp" line="1142"/>
         <source>Name</source>
         <translation>Naam</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1062"/>
+        <location filename="../../DetailedWindow.cpp" line="1155"/>
         <source>Type</source>
         <translation>Type</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1072"/>
+        <location filename="../../DetailedWindow.cpp" line="1165"/>
         <source>String</source>
         <translation>String</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1073"/>
+        <location filename="../../DetailedWindow.cpp" line="1166"/>
         <source>Text</source>
         <translation>Tekst</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1074"/>
+        <location filename="../../DetailedWindow.cpp" line="1167"/>
         <source>Date</source>
         <translation>Datum</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1075"/>
+        <location filename="../../DetailedWindow.cpp" line="1168"/>
         <source>Number</source>
         <translation>Nummer</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1076"/>
+        <location filename="../../DetailedWindow.cpp" line="1169"/>
         <source>Phone Number</source>
         <translation>Telefoonnummer</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1077"/>
+        <location filename="../../DetailedWindow.cpp" line="1170"/>
         <source>Password</source>
         <translation>Wachtwoord</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1078"/>
+        <location filename="../../DetailedWindow.cpp" line="1171"/>
         <source>URL</source>
         <translation>URL</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1083"/>
+        <location filename="../../DetailedWindow.cpp" line="1176"/>
         <source>Order</source>
         <translation>Volgorde</translation>
     </message>
@@ -57,259 +57,260 @@
 <context>
     <name>DetailWindow</name>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="63"/>
+        <location filename="../../DetailedWindow.cpp" line="82"/>
         <source>Copy of </source>
         <translation>Kopie van</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="110"/>
+        <location filename="../../DetailedWindow.cpp" line="129"/>
+        <location filename="../../DetailedWindow.cpp" line="352"/>
         <source>Save</source>
         <translation>Opslaan</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="112"/>
-        <location filename="../../DetailedWindow.cpp" line="739"/>
-        <location filename="../../DetailedWindow.cpp" line="752"/>
+        <location filename="../../DetailedWindow.cpp" line="131"/>
+        <location filename="../../DetailedWindow.cpp" line="798"/>
+        <location filename="../../DetailedWindow.cpp" line="811"/>
         <source>Delete</source>
         <translation>Verwijder</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="113"/>
+        <location filename="../../DetailedWindow.cpp" line="132"/>
         <source>Change Face Pict.</source>
         <translation>Wijzig pasfoto</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="114"/>
+        <location filename="../../DetailedWindow.cpp" line="133"/>
         <source>Mirror Face Pict.</source>
         <translation>Draai pasfoto</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="115"/>
+        <location filename="../../DetailedWindow.cpp" line="134"/>
         <source>Change Back Pict.</source>
         <translation>Wijzig achtergr. foto</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="116"/>
+        <location filename="../../DetailedWindow.cpp" line="135"/>
         <source>Mirror Back Pict.</source>
         <translation>Draai achtergr. foto</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="117"/>
+        <location filename="../../DetailedWindow.cpp" line="136"/>
         <source>Delete Face Pict.</source>
         <translation>Verwijder pasfoto</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="118"/>
+        <location filename="../../DetailedWindow.cpp" line="137"/>
         <source>Delete Back Pict.</source>
         <translation>Verwijder achtergr. foto</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="119"/>
+        <location filename="../../DetailedWindow.cpp" line="138"/>
         <source>Modify fields</source>
         <translation>Wijzig velden</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="124"/>
+        <location filename="../../DetailedWindow.cpp" line="146"/>
         <source>New Card</source>
         <translation>Nieuwe kaart</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="125"/>
+        <location filename="../../DetailedWindow.cpp" line="147"/>
         <source>Edit Card</source>
         <translation>Bewerk kaart</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="126"/>
+        <location filename="../../DetailedWindow.cpp" line="148"/>
         <source>New Card like this</source>
         <translation>Nieuwe kaart zoals deze</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="127"/>
+        <location filename="../../DetailedWindow.cpp" line="149"/>
         <source>Duplicate Card</source>
         <translation>Kopieer kaart</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="128"/>
+        <location filename="../../DetailedWindow.cpp" line="150"/>
         <source>Export Face Pict.</source>
         <translation>Exporteer pasfoto</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="129"/>
+        <location filename="../../DetailedWindow.cpp" line="151"/>
         <source>Export Back Pict.</source>
         <translation>Exporteer achtergr. foto</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="156"/>
+        <location filename="../../DetailedWindow.cpp" line="178"/>
         <source>Name</source>
         <translation>Naam</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="167"/>
+        <location filename="../../DetailedWindow.cpp" line="189"/>
         <source>Group Name</source>
         <translation>Groepnaam</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="185"/>
+        <location filename="../../DetailedWindow.cpp" line="207"/>
         <source>Membership Info</source>
         <translation>Info lidmaatschap</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="186"/>
+        <location filename="../../DetailedWindow.cpp" line="208"/>
         <source>Password</source>
         <translation>Wachtwoord</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="187"/>
+        <location filename="../../DetailedWindow.cpp" line="209"/>
         <source>Credit Card</source>
         <translation>Creditcard</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="188"/>
+        <location filename="../../DetailedWindow.cpp" line="210"/>
         <source>Bank Account</source>
         <translation>Bankrekening</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="189"/>
+        <location filename="../../DetailedWindow.cpp" line="211"/>
         <source>Health Numbers</source>
         <translation>Gezondheidsnummers</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="190"/>
+        <location filename="../../DetailedWindow.cpp" line="212"/>
         <source>Passport Info</source>
         <translation>Info paspoort</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="191"/>
+        <location filename="../../DetailedWindow.cpp" line="213"/>
         <source>Note Card</source>
         <translation>Notitiekaart</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="192"/>
+        <location filename="../../DetailedWindow.cpp" line="214"/>
         <source>Car Info</source>
         <translation>Kaart info</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="193"/>
+        <location filename="../../DetailedWindow.cpp" line="215"/>
         <source>Cellular Phone</source>
         <translation>Mobiele telefoon</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="194"/>
+        <location filename="../../DetailedWindow.cpp" line="216"/>
         <source>Serial Number Software</source>
         <translation>Serienummer software</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="195"/>
+        <location filename="../../DetailedWindow.cpp" line="217"/>
         <source>Serial Number Hardware</source>
         <translation>Serienummer hardware</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="196"/>
+        <location filename="../../DetailedWindow.cpp" line="218"/>
         <source>Web site</source>
         <translation>Website</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="197"/>
+        <location filename="../../DetailedWindow.cpp" line="219"/>
         <source>ID Card</source>
         <translation>ID kaart</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="198"/>
+        <location filename="../../DetailedWindow.cpp" line="220"/>
         <source>Social Security Number</source>
         <translation>Sociale verzekeringsnummer</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="199"/>
+        <location filename="../../DetailedWindow.cpp" line="221"/>
         <source>Email Account</source>
         <translation>E-mail account</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="200"/>
+        <location filename="../../DetailedWindow.cpp" line="222"/>
         <source>Driver&apos;s License</source>
         <translation>Rijbewijs</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="201"/>
+        <location filename="../../DetailedWindow.cpp" line="223"/>
         <source>Others</source>
         <translation>Anders</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="205"/>
+        <location filename="../../DetailedWindow.cpp" line="227"/>
         <source>Type</source>
         <translation>Type</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="473"/>
-        <location filename="../../DetailedWindow.cpp" line="519"/>
+        <location filename="../../DetailedWindow.cpp" line="533"/>
+        <location filename="../../DetailedWindow.cpp" line="579"/>
         <source>Click to see</source>
         <translation>Klik om te bekijken</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="573"/>
+        <location filename="../../DetailedWindow.cpp" line="632"/>
         <source>Card description is missing</source>
         <translation>Kaartbeschrijving ontbreekt</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="583"/>
+        <location filename="../../DetailedWindow.cpp" line="642"/>
         <source>Type card is missing</source>
         <translation>Type kaart ontbreekt</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="737"/>
-        <location filename="../../DetailedWindow.cpp" line="750"/>
+        <location filename="../../DetailedWindow.cpp" line="796"/>
+        <location filename="../../DetailedWindow.cpp" line="809"/>
         <source>Edit</source>
         <translation>Bewerk</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="738"/>
-        <location filename="../../DetailedWindow.cpp" line="751"/>
+        <location filename="../../DetailedWindow.cpp" line="797"/>
+        <location filename="../../DetailedWindow.cpp" line="810"/>
         <source>Mirror</source>
         <translation>Draai</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="742"/>
+        <location filename="../../DetailedWindow.cpp" line="801"/>
         <source>Export Face</source>
         <translation>Exporteer voorkant</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="755"/>
+        <location filename="../../DetailedWindow.cpp" line="814"/>
         <source>Export Back</source>
         <translation>Exporteer achterkant</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="773"/>
+        <location filename="../../DetailedWindow.cpp" line="835"/>
         <source>Choose card face image file</source>
         <translation>Kies bestand voorkant kaart</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="775"/>
-        <location filename="../../DetailedWindow.cpp" line="913"/>
+        <location filename="../../DetailedWindow.cpp" line="837"/>
+        <location filename="../../DetailedWindow.cpp" line="979"/>
         <source>Images (*.png);;</source>
         <translation>Afbeeldingen PNG (*.png)</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="787"/>
+        <location filename="../../DetailedWindow.cpp" line="850"/>
         <source>Choose card face image</source>
         <translation>Kies afbeelding voorkant kaart</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="789"/>
-        <location filename="../../DetailedWindow.cpp" line="928"/>
+        <location filename="../../DetailedWindow.cpp" line="852"/>
+        <location filename="../../DetailedWindow.cpp" line="995"/>
         <source>Images (*.png *.jpg *.gif *.jpeg);;</source>
         <translation>Afbeeldingen (*.png *.jpg *.gif *.jpeg)</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="911"/>
+        <location filename="../../DetailedWindow.cpp" line="977"/>
         <source>Choose card back image file</source>
         <translation>Kies bestand achterkant kaart</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="926"/>
+        <location filename="../../DetailedWindow.cpp" line="993"/>
         <source>Choose card back image</source>
         <translation>Kies afbeelding achterkant kaart</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="966"/>
+        <location filename="../../DetailedWindow.cpp" line="1052"/>
         <source>Are you sure you want to discard changes?</source>
         <translation>Wijzigingen niet doorvoeren?</translation>
     </message>
@@ -347,17 +348,22 @@
         <translation>Over Wallet</translation>
     </message>
     <message>
-        <location filename="../../LoginDialog.cpp" line="239"/>
+        <location filename="../../LoginDialog.cpp" line="221"/>
+        <source>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;qtWallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Developed by &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icons by http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;if you think that qtWallet is useful for you, please&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt;&lt;/qt&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../LoginDialog.cpp" line="243"/>
         <source>Password is required</source>
         <translation>Wachtwoord benodigd</translation>
     </message>
     <message>
-        <location filename="../../LoginDialog.cpp" line="256"/>
+        <location filename="../../LoginDialog.cpp" line="260"/>
         <source>For verification, please, enter your password again</source>
         <translation>Voer uw wachtwoord ter verificatie nogmaals in</translation>
     </message>
     <message>
-        <location filename="../../LoginDialog.cpp" line="269"/>
+        <location filename="../../LoginDialog.cpp" line="273"/>
         <source>Invalid password, please enter again</source>
         <translation>Wachtwoord onjuist, probeer nogmaals</translation>
     </message>
@@ -389,13 +395,13 @@
     </message>
     <message>
         <location filename="../../eWallet.cpp" line="366"/>
-        <location filename="../../eWallet.cpp" line="819"/>
+        <location filename="../../eWallet.cpp" line="818"/>
         <source>&lt;All&gt;</source>
         <translation>&lt;Alle&gt;</translation>
     </message>
     <message>
         <location filename="../../eWallet.cpp" line="385"/>
-        <location filename="../../eWallet.cpp" line="828"/>
+        <location filename="../../eWallet.cpp" line="827"/>
         <source>&lt;No Group&gt;</source>
         <translation>&lt;Geen groep&gt;</translation>
     </message>
@@ -748,117 +754,121 @@
         <translation>Datum uitgave</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="908"/>
+        <location filename="../../eWallet.cpp" line="907"/>
         <source>About</source>
         <translation>Over</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="910"/>
+        <location filename="../../eWallet.cpp" line="909"/>
         <source>Delete DB</source>
         <translation>Verwijder database</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="912"/>
-        <location filename="../../eWallet.cpp" line="923"/>
+        <location filename="../../eWallet.cpp" line="911"/>
+        <location filename="../../eWallet.cpp" line="922"/>
         <source>Exit</source>
         <translation>Afsluiten</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="915"/>
+        <location filename="../../eWallet.cpp" line="914"/>
         <source>New</source>
         <translation>Nieuw</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="917"/>
-        <location filename="../../eWallet.cpp" line="1391"/>
+        <location filename="../../eWallet.cpp" line="916"/>
+        <location filename="../../eWallet.cpp" line="1390"/>
         <source>Edit</source>
         <translation>Bewerk</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="918"/>
+        <location filename="../../eWallet.cpp" line="917"/>
         <source>Invert Sort</source>
         <translation>Omgekeerd sorteren</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="919"/>
+        <location filename="../../eWallet.cpp" line="918"/>
         <source>Import</source>
         <translation>Importeren</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="920"/>
+        <location filename="../../eWallet.cpp" line="919"/>
         <source>Export</source>
         <translation>Exporteren</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="922"/>
+        <location filename="../../eWallet.cpp" line="921"/>
         <source>Change Password</source>
         <translation>Wijzig wachtwoord</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="982"/>
+        <location filename="../../eWallet.cpp" line="981"/>
         <source>Are you sure you want to remove it?</source>
         <translation>Weet u zeker dat u dit wilt verwijderen?</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1130"/>
+        <location filename="../../eWallet.cpp" line="1129"/>
         <source>Choose import file</source>
         <translation>Kies importbestand</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1132"/>
-        <location filename="../../eWallet.cpp" line="1407"/>
+        <location filename="../../eWallet.cpp" line="1131"/>
+        <location filename="../../eWallet.cpp" line="1409"/>
         <source>Text files (*.txt);;</source>
         <translation>Tekstbestanden (*.txt)</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1380"/>
+        <location filename="../../eWallet.cpp" line="1379"/>
         <source>Rename</source>
         <translation>Hernoem</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1381"/>
-        <location filename="../../eWallet.cpp" line="1394"/>
+        <location filename="../../eWallet.cpp" line="1380"/>
+        <location filename="../../eWallet.cpp" line="1393"/>
         <source>Delete</source>
         <translation>Verwijder</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1390"/>
+        <location filename="../../eWallet.cpp" line="1389"/>
         <source>View</source>
         <translation>Bekijk</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1392"/>
+        <location filename="../../eWallet.cpp" line="1391"/>
         <source>New like this</source>
         <translation>Nieuwe zoals deze</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1393"/>
+        <location filename="../../eWallet.cpp" line="1392"/>
         <source>Duplicate</source>
         <translation>Kopieer</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1405"/>
+        <location filename="../../eWallet.cpp" line="1407"/>
         <source>Choose export file</source>
         <translation>Kies exportbestand</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1610"/>
+        <location filename="../../eWallet.cpp" line="1615"/>
         <source>About Wallet</source>
         <translation>Over Wallet</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1645"/>
+        <location filename="../../eWallet.cpp" line="1615"/>
+        <source>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;qtWallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Developed by &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icons by http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;if you think that qtWallet is useful for you, please&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt;&lt;/qt&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="1654"/>
         <source>Changing password, please wait until application quits</source>
         <translation>Wijzigt wachtwoord. Wacht a.u.b. tot applicatie afsluit</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1651"/>
-         <source>Password changed successfully, application will exit</source>
+        <location filename="../../eWallet.cpp" line="1660"/>
+        <source>Password changed successfully, application will exit</source>
         <translation>Wachtwoord succesvol gewijzigd. Applicatie zal afsluiten</translation>
-        
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1653"/>
+        <location filename="../../eWallet.cpp" line="1662"/>
         <source>Password CANNOT BE changed, because %1, and application will exit</source>
         <translation>Wachtwoord NIET gewijzigd vanwege %1. Applicatie zal afsluiten</translation>
     </message>
